@@ -1,8 +1,8 @@
 # pylint: disable=no-self-argument
+import warnings
 from enum import Enum
 from pathlib import Path
-import warnings
-from typing import Any, Dict, List, Optional, Tuple, Union, Literal
+from typing import Any, Dict, List, Literal, Optional, Tuple, Union
 
 from pydantic import (  # pylint: disable=no-name-in-module
     AnyHttpUrl,
@@ -13,10 +13,9 @@ from pydantic import (  # pylint: disable=no-name-in-module
 )
 from pydantic.env_settings import SettingsSourceCallable
 
-from optimade import __version__, __api_version__
+from optimade import __api_version__, __version__
 from optimade.models import Implementation, Provider
 
-
 DEFAULT_CONFIG_FILE_PATH: str = str(Path.home().joinpath(".optimade.json"))
 """Default configuration file path.
 
@@ -87,6 +86,7 @@ def config_file_settings(settings: BaseSettings) -> Dict[str, Any]:
     """
     import json
     import os
+
     import yaml
 
     encoding = settings.__config__.env_file_encoding
@@ -153,7 +153,7 @@ class ServerConfig(BaseSettings):
         description="Which database backend to use out of the supported backends.",
     )
 
-    elastic_hosts: Optional[List[Dict]] = Field(
+    elastic_hosts: Optional[Union[str, List[str], Dict, List[Dict]]] = Field(
         None, description="Host settings to pass through to the `Elasticsearch` class."
     )
 
